Plugins — Ibid v0.1.1 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Ibid v0.1.1 documentation »

# Plugins

Plugins are at the heart of Ibid, they provide all the features. There are core plugins that provide features such as account management, and plugin management. Then there are feature plugins, such as factoids, RSS/Atom feeds, dictionary lookup, etc.

- Factoids
  - Basics
  - Fancy factoids
  - Searching
  - Modification

### Navigation

- index
- modules |
- next |
- previous |
- Ibid v0.1.1 documentation »